from kiteconnect import KiteConnect
from pydantic import BaseModel


class PlaceNormalOrder(BaseModel):
    order_id: str


class PlaceNormalOrderModel(BaseModel):
    kite_instance: KiteConnect
    stock_name: str
    quantity: int
    order_type: str

    class Config:
        arbitrary_types_allowed = True

    def __init__(self, kite_instance: KiteConnect):
        super().__init__(kite_instance=kite_instance)

    def set_stock_name(self, stock_name: str) -> 'PlaceNormalOrderModel':
        self.stock_name = stock_name
        return self

    def set_quantity(self, quantity: int) -> 'PlaceNormalOrderModel':
        self.quantity = quantity
        return self

    def set_order_type(self, order_type: str) -> 'PlaceNormalOrderModel':
        self.order_type = order_type
        return self

    def execute(self) -> 'PlaceNormalOrder':
        order_id = self.kite_instance.place_order(variety=self.kite_instance.VARIETY_REGULAR, exchange=self.kite_instance.EXCHANGE_NSE,
                                                  tradingsymbol=self.stock_name, transaction_type=self.order_type,
                                                  quantity=self.quantity, product=self.kite_instance.PRODUCT_MIS,
                                                  order_type=self.kite_instance.ORDER_TYPE_MARKET)

        return PlaceNormalOrder(order_id=order_id)



from pydantic import BaseModel
from kiteconnect import (KiteConnect, KiteTicker)


class SessionAccessToken(BaseModel):
    access_token: str


class GenerateSessionModel(BaseModel):
    request_token: str = None
    api_secret: str = None
    kite_instance: KiteConnect = None

    class Config:
        arbitrary_types_allowed = True

    def __init__(self, kite_instance: KiteConnect):
        super().__init__(kite_instance=kite_instance)

    def set_request_token(self, request_token: str) -> 'GenerateSessionModel':
        self.request_token = request_token
        return self

    def set_api_secret(self, api_secret: str) -> 'GenerateSessionModel':
        self.api_secret = api_secret
        return self

    def execute(self) -> 'SessionAccessToken':
        access_token = self.kite_instance.generate_session(
            self.request_token, self.api_secret)["access_token"]
        access_token = "access token"
        return SessionAccessToken(
            access_token=access_token
        )



from kiteconnect import KiteConnect
from pydantic import BaseModel


class LoginUrl(BaseModel):
    login_url: str


class LoginUrlModel(BaseModel):
    kite_instance: KiteConnect = None

    class Config:
        arbitrary_types_allowed = True

    def __init__(self, kite_instance: KiteConnect):
        super().__init__(kite_instance=kite_instance)

    def execute(self) -> 'LoginUrl':
        login_url = self.kite_instance.login_url()
        login_url = "login url"
        return LoginUrl(login_url=login_url)



from kiteconnect import (KiteConnect)

from just_design_phase.kite_login import kite

from just_design_phase.models.place_normal_order_model import PlaceNormalOrderModel
from just_design_phase.models.generate_session_model import GenerateSessionModel
from just_design_phase.models.login_url_model import LoginUrlModel


class KiteConnectLite:
    def __init__(self, api_key: str):
        self.kite_api_key: str = api_key
        self.kite_instance = KiteConnect(api_key=self.kite_api_key)

    def login_url(self) -> 'LoginUrlModel':
        return LoginUrlModel(self.kite_instance)

    def generate_session(self) -> 'GenerateSessionModel':
        return GenerateSessionModel(self.kite_instance)

    def place_normal_order(self) -> 'PlaceNormalOrderModel':
        return PlaceNormalOrderModel(self.kite_instance)


kite



import os

from kiteconnect import KiteConnect

PROJECT_ROOT = os.path.abspath("")

print(PROJECT_ROOT)

KITE_API_KEY = os.getenv("KITE_API_KEY")
KITE_API_SECRET = os.getenv("KITE_API_SECRET")


def login():
    kite = KiteConnect(api_key=KITE_API_KEY)
    with open(PROJECT_ROOT + "/sample.txt", "w") as file:
        file.write("Hello World")


kite = login()
